==> wordpress-2.0.8-da_DK.tar.gz: wordpress/wp-content/themes/default/comments.php <==
<?php // Slet ikke disse linjer
	if ('comments.php' == basename($_SERVER['SCRIPT_FILENAME']))
		die ('K&oslash;r ikke denne side direkte. Tak!');

        if (!empty($post->post_password)) { // hvis der er et kodeord
            if ($_COOKIE['wp-postpass_' . COOKIEHASH] != $post->post_password) {  // og det ikke passer sammen med cookien
				?>
				
				<p class="nocomments">Dette indl&aelig;g er kodeordsbeskyttet. Skriv dit kodeord for at se kommentarer.<p>
				
				<?php
				return;
            }
        }

		/* Denne variabel s&oslash;rger for at skifte kommentar-baggrunden */
		$oddcomment = 'alt';
?>

<!-- Du kan starte med at redigere her. -->

<?php if ($comments) : ?>
	<h3 id="comments"><?php comments_number('Ingen kommentarer', 'En kommentar', '% kommentarer' );?> til &#8220;<?php the_title(); ?>&#8221;</h3> 

	<ol class="commentlist">

	<?php foreach ($comments as $comment) : ?>

		<li class="<?php echo $oddcomment; ?>" id="comment-<?php comment_ID() ?>">
			<cite><?php comment_author_link() ?></cite> siger:
			<?php if ($comment->comment_approved == '0') : ?>
			<em>Din kommentar afventer bed&oslash;mmelse.</em>
			<?php endif; ?>
			<br />

			<small class="commentmetadata"><a href="#comment-<?php comment_ID() ?>" title=""><?php comment_date('j. F Y') ?> kl. <?php comment_time('H:i') ?></a> <?php edit_comment_link('red.','',''); ?></small>

			<?php comment_text() ?>

		</li>

	<?php /* Skifter hver anden kommentar til en anden class */	
		if ('alt' == $oddcomment) $oddcomment = '';
		else $oddcomment = 'alt';
	?>

	<?php endforeach; /* slut for hver kommentar */ ?>

	</ol>

 <?php else : // dette vises hvis der ingen kommentarer er ?>

  <?php if ('open' == $post->comment_status) : ?> 
		<!-- Hvis kommentarer er &aring;bne, men der ingen er. -->
		
	 <?php else : // kommentarer er lukket ?>
		<!-- Hvis kommentarer er lukket. -->
		<p class="nocomments">Der er lukket for kommentarer.</p>
		
	<?php endif; ?>
<?php endif; ?>


<?php if ('open' == $post->comment_status) : ?>

<h3 id="respond">Efterlad en kommentar</h3>

<?php if ( get_option('comment_registration') && !$user_ID ) : ?>
<p>Du skal v&aelig;re <a href="<?php echo get_option('siteurl'); ?>/wp-login.php?redirect_to=<?php the_permalink(); ?>">logget ind</a> for at skrive en kommentar.</p>
<?php else : ?>

<form action="<?php echo get_option('siteurl'); ?>/wp-comments-post.php" method="post" id="commentform">

<?php if ( $user_ID ) : ?>

<p>Logget ind som <a href="<?php echo get_option('siteurl'); ?>/wp-admin/profile.php"><?php echo $user_identity; ?></a>. <a href="<?php echo get_option('siteurl'); ?>/wp-login.php?action=logout" title="Log ud fra denne konto">Log ud &raquo;</a></p>

<?php else : ?>

<p><input type="text" name="author" id="author" value="<?php echo $comment_author; ?>" size="22" tabindex="1" />
<label for="author"><small>Navn <?php if ($req) echo "(n&oslash;dvendigt)"; ?></small></label></p>

<p><input type="text" name="email" id="email" value="<?php echo $comment_author_email; ?>" size="22" tabindex="2" />
<label for="email"><small>E-mail (offentligg&oslash;res ikke) <?php if ($req) echo "(n&oslash;dvendigt)"; ?></small></label></p>

<p><input type="text" name="url" id="url" value="<?php echo $comment_author_url; ?>" size="22" tabindex="3" />
<label for="url"><small>Hjemmeside</small></label></p>

<?php endif; ?>

<!--<p><small><strong>XHTML:</strong> Du kan bruge disse tags: <?php echo allowed_tags(); ?></small></p>-->

<p><textarea name="comment" id="comment" cols="100%" rows="10" tabindex="4"></textarea></p>

<p><input name="submit" type="submit" id="submit" tabindex="5" value="Send kommentar" />
<input type="hidden" name="comment_post_ID" value="<?php echo $id; ?>" />
</p>
<?php do_action('comment_form', $post->ID); ?>

</form>

<?php endif; // Hvis registrering er kr&aelig;vet men ikke logget ind ?>

<?php endif; // if you delete this the sky will fall on your head ?>

==> wordpress-2.1.1-da_DK.tar.gz: wordpress/wp-content/themes/default/comments.php <==
<?php // Slet ikke disse linjer
	if ('comments.php' == basename($_SERVER['SCRIPT_FILENAME']))
		die ('K&oslash;r ikke denne side direkte. Tak!');

	if (!empty($post->post_password)) { // hvis der er et kodeord
		if ($_COOKIE['wp-postpass_' . COOKIEHASH] != $post->post_password) {  // og det ikke passer sammen med cookien
			?>

			<p class="nocomments">Dette indl&aelig;g er kodeordsbeskyttet. Skriv dit kodeord for at se kommentarer.<p>

			<?php
			return;
		}
	}

	/* Denne variabel skifter kommentarbaggrunden */
	$oddcomment = 'alt';
?>

<!-- Du kan starte med at redigere her. -->

<?php if ($comments) : ?>
	<h3 id="comments"><?php comments_number('Ingen kommentarer', 'En kommentar', '% kommentarer' );?> til &#8220;<?php the_title(); ?>&#8221;</h3>

	<ol class="commentlist">

	<?php foreach ($comments as $comment) : ?>

		<li class="<?php echo $oddcomment; ?>" id="comment-<?php comment_ID() ?>">
			<cite><?php comment_author_link() ?></cite> siger:
			<?php if ($comment->comment_approved == '0') : ?>
			<em>Din kommentar afventer bed&oslash;mmelse.</em>
			<?php endif; ?>
			<br />

			<small class="commentmetadata"><a href="#comment-<?php comment_ID() ?>" title=""><?php comment_date('j. F Y') ?> kl. <?php comment_time('H:i') ?></a> <?php edit_comment_link('red.','',''); ?></small>

			<?php comment_text() ?>

		</li>

	<?php /* Skifter hver anden kommentar til en anden class */	
		if ('alt' == $oddcomment) $oddcomment = '';
		else $oddcomment = 'alt';
	?>

	<?php endforeach; /* slut for hver kommentar */ ?>

	</ol>

 <?php else : // dette vises hvis der ingen kommentarer er ?>

	<?php if ('open' == $post->comment_status) : ?>
		<!-- Hvis kommentarer er aabne, men der ingen er. -->

	 <?php else : // kommentarer er lukket ?>
		<!-- Hvis kommentarer er lukket. -->
		<p class="nocomments">Der er lukket for kommentarer.</p>

	<?php endif; ?>
<?php endif; ?>


<?php if ('open' == $post->comment_status) : ?>

<h3 id="respond">Skriv en kommentar</h3>

<?php if ( get_option('comment_registration') && !$user_ID ) : ?>
<p>Du skal v&aelig;re <a href="<?php echo get_option('siteurl'); ?>/wp-login.php?redirect_to=<?php the_permalink(); ?>">logget ind</a> for at skrive en kommentar.</p>
<?php else : ?>

<form action="<?php echo get_option('siteurl'); ?>/wp-comments-post.php" method="post" id="commentform">

<?php if ( $user_ID ) : ?>

<p>Logget ind som <a href="<?php echo get_option('siteurl'); ?>/wp-admin/profile.php"><?php echo $user_identity; ?></a>. <a href="<?php echo get_option('siteurl'); ?>/wp-login.php?action=logout" title="Log ud fra denne konto">Log ud &raquo;</a></p>

<?php else : ?>

<p><input type="text" name="author" id="author" value="<?php echo $comment_author; ?>" size="22" tabindex="1" />
<label for="author"><small>Navn <?php if ($req) echo "(n&oslash;dvendigt)"; ?></small></label></p>

<p><input type="text" name="email" id="email" value="<?php echo $comment_author_email; ?>" size="22" tabindex="2" />
<label for="email"><small>E-mail (offentligg&oslash;res ikke) <?php if ($req) echo "(n&oslash;dvendig)"; ?></small></label></p>

<p><input type="text" name="url" id="url" value="<?php echo $comment_author_url; ?>" size="22" tabindex="3" />
<label for="url"><small>Webside</small></label></p>

<?php endif; ?>

<!--<p><small><strong>XHTML:</strong> Du kan bruge disse tags: <?php echo allowed_tags(); ?></small></p>-->

<p><textarea name="comment" id="comment" cols="100%" rows="10" tabindex="4"></textarea></p>

<p><input name="submit" type="submit" id="submit" tabindex="5" value="Send kommentar" />
<input type="hidden" name="comment_post_ID" value="<?php echo $id; ?>" />
</p>
<?php do_action('comment_form', $post->ID); ?>

</form>

<?php endif; // Hvis registrering er kraevet men ikke logget ind ?>

<?php endif; // if you delete this the sky will fall on your head ?>
